package com.home.searchText;

import java.text.Collator;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Locale;

public class SampleTextSearch {

	public static void main(String[] args) {

		// This data is based on an example in Java Class Libraries,

		List<String> wordList = Arrays.asList( "bc", "bc", "bc", "bc", "Abc", "abc", "ABC" ) ;

		System.out.println( "Sort results are based on the  'Collation Strength' values " );
		System.out.println(wordList + " - Original Data");
		sort(wordList, Strength.Primary);
		sort(wordList, Strength.Secondary);
		sort(wordList, Strength.Tertiary);

		System.out.println(EMPTY_LINE);
		System.out.println("Tertiary Collation - Case sensitive : ");
		List<String> wordsForCase = Arrays.asList("cache", "CACHE", "Cache");
		System.out.println(wordsForCase + " - Original Data");
		sort(wordsForCase, Strength.Primary);
		sort(wordsForCase, Strength.Secondary);
		sort(wordsForCase, Strength.Tertiary);

		System.out.println(EMPTY_LINE);
		System.out.println("Secondary Collation - Accent sensitive.");
		System.out.println("Compare with no accents present: ");
		compare("abc", "ABC", Strength.Primary);
		compare("abc", "ABC", Strength.Secondary);
		compare("abc", "ABC", Strength.Tertiary);

		System.out.println(EMPTY_LINE);
		System.out.println("Compare with accents present: ");
		compare("abc", "BC", Strength.Primary);
		compare("abc", "BC", Strength.Secondary);
		compare("abc", "BC", Strength.Tertiary);
	}

	// PRIVATE //
	private static final String EMPTY_LINE = "";
	private static final Locale TEST_LOCALE = Locale.FRANCE;

	/** Transform some Collator 'int' consts into an equivalent enum. */
	private enum Strength {
		Primary(Collator.PRIMARY), // base char
		Secondary(Collator.SECONDARY), // base char + accent
		Tertiary(Collator.TERTIARY), // base char + accent + case
		Identical(Collator.IDENTICAL); // base char + accent + case + bits

		int getStrength() {
			return fStrength;
		}

		private int fStrength;

		private Strength(int aStrength) {
			fStrength = aStrength;
		}
	}

	private static void sort(List<String> aWords, Strength aStrength) {
		Collator collator = Collator.getInstance(TEST_LOCALE);
		collator.setStrength(aStrength.getStrength());
		Collections.sort(aWords, collator);
		System.out.println(aWords.toString() + " " + aStrength);
	}

	private static void compare(String str1, String str2, Strength aStrength) {
		Collator collator = Collator.getInstance(TEST_LOCALE);
		collator.setStrength(aStrength.getStrength());
		int comparison = collator.compare(str1, str2);
		if (comparison == 0) {
			System.out.println("String : " + str1 + " and " + str2 + " are same with Strength - " + aStrength);
		} else {
			System.out.println("String : " + str1 + " and " + str2 + " are different with Strength- " + aStrength);
		}
	}
}
